[Libreoffice-commits] online.git: 4 commits - loolwsd/bundled loolwsd/configure.ac loolwsd/LOOLSession.cpp loolwsd/loolwsd.spec.in

Tor Lillqvist tml at collabora.com
Thu May 28 00:35:41 PDT 2015


 loolwsd/LOOLSession.cpp                                      |   25 +++++------
 loolwsd/bundled/include/LibreOfficeKit/LibreOfficeKitEnums.h |    8 +--
 loolwsd/configure.ac                                         |    2 
 loolwsd/loolwsd.spec.in                                      |    8 +--
 4 files changed, 22 insertions(+), 21 deletions(-)

New commits:
commit 8166e9494f38ac2e81a89ee3bbee39db8ff81465
Author: Tor Lillqvist <tml at collabora.com>
Date:   Thu May 28 10:35:07 2015 +0300

    Post-release bump to 1.0.23

diff --git a/loolwsd/configure.ac b/loolwsd/configure.ac
index 4936d4a..a5f391b 100644
--- a/loolwsd/configure.ac
+++ b/loolwsd/configure.ac
@@ -3,7 +3,7 @@
 
 AC_PREREQ([2.69])
 
-AC_INIT([loolwsd], [1.0.21], [libreoffice at collabora.com])
+AC_INIT([loolwsd], [1.0.23], [libreoffice at collabora.com])
 
 AM_INIT_AUTOMAKE([1.11 silent-rules])
 
commit 5150db06b9277e8a2dc2f5663281ab746cfc7af4
Author: Tor Lillqvist <tml at collabora.com>
Date:   Thu May 28 10:31:39 2015 +0300

    Adapt to work with either 5.0 or 5.1 packages from TDF

diff --git a/loolwsd/loolwsd.spec.in b/loolwsd/loolwsd.spec.in
index 5cc4dc5..6ee3c38 100644
--- a/loolwsd/loolwsd.spec.in
+++ b/loolwsd/loolwsd.spec.in
@@ -28,9 +28,7 @@ Requires:       libcap libcap-progs libpng libPocoFoundation30 >= 1.6.0 libPocoN
 %define owner lool
 %define group lool
 
-# This works for now only with the TDF nightly builds or similar, I think
-%define sofficeversion 5.0
-%define sofficepackage libreofficedev%{sofficeversion}
+# This works for now only with the TDF nightly builds of 5.0 or 5.1, I think
 
 %description
 
@@ -64,7 +62,9 @@ mkdir -p /var/cache/loolwsd && chmod og+w /var/cache/loolwsd
 
 # Figure out where LO is installed, let's hope it is not a mount point
 # Create a directory for loolwsd on the same file system
-loroot=`rpm -ql %{sofficepackage} | grep '/soffice$' | sed -e 's-/program/soffice--'`
+# First look for TDF libreofficedev5.1, then 5.0
+loroot=`rpm -ql libreofficedev5.1 | grep '/soffice$' | sed -e 's-/program/soffice--'`
+test -z "$loroot" && loroot=`rpm -ql libreofficedev5.0 | grep '/soffice$' | sed -e 's-/program/soffice--'`
 loolparent=`cd ${loroot} && cd .. && /bin/pwd`
 
 rm -rf ${loolparent}/lool
commit fd7f83df924e73a1b642019802d08194325a9e4a
Author: Tor Lillqvist <tml at collabora.com>
Date:   Thu May 28 10:27:43 2015 +0300

    Update from master

diff --git a/loolwsd/LOOLSession.cpp b/loolwsd/LOOLSession.cpp
index bdb4c48..ce273b7 100644
--- a/loolwsd/LOOLSession.cpp
+++ b/loolwsd/LOOLSession.cpp
@@ -214,6 +214,19 @@ bool MasterProcessSession::handleInput(char *buffer, int length)
         }
         return loadDocument(buffer, length, tokens);
     }
+    else if (tokens[0] != "status" &&
+             tokens[0] != "tile" &&
+             tokens[0] != "key" &&
+             tokens[0] != "mouse" &&
+             tokens[0] != "uno" &&
+             tokens[0] != "selecttext" &&
+             tokens[0] != "selectgraphic" &&
+             tokens[0] != "resetselection" &&
+             tokens[0] != "saveas")
+    {
+        sendTextFrame("error: cmd=" + tokens[0] + " kind=unknown");
+        return false;
+    }
     else if (_docURL == "")
     {
         sendTextFrame("error: cmd=" + tokens[0] + " kind=nodocloaded");
@@ -233,18 +246,6 @@ bool MasterProcessSession::handleInput(char *buffer, int length)
         // LibreOfficeKitDocument session, i.e. need to be handled in
         // a child process.
 
-        if (tokens[0] != "key" &&
-            tokens[0] != "mouse" &&
-            tokens[0] != "uno" &&
-            tokens[0] != "selecttext" &&
-            tokens[0] != "selectgraphic" &&
-            tokens[0] != "resetselection" &&
-            tokens[0] != "saveas")
-        {
-            sendTextFrame("error: cmd=" + tokens[0] + " kind=unknown");
-            return false;
-        }
-
         if (_peer.expired())
             dispatchChild();
         forwardToPeer(buffer, length);


More information about the Libreoffice-commits mailing list
diff --git a/loolwsd/bundled/include/LibreOfficeKit/LibreOfficeKitEnums.h b/loolwsd/bundled/include/LibreOfficeKit/LibreOfficeKitEnums.h
index bbcd5b9..66237e4 100644
--- a/loolwsd/bundled/include/LibreOfficeKit/LibreOfficeKitEnums.h
+++ b/loolwsd/bundled/include/LibreOfficeKit/LibreOfficeKitEnums.h
@@ -143,12 +143,12 @@ typedef enum
     LOK_CALLBACK_SEARCH_NOT_FOUND,
 
     /**
      * Number of pages changed in the document.
      *
-     * Clients should assume that data returned by an earlier
-     * lok::Document::getDocumentSize() call is no longer valid.
+     * Payload format is "width, height", i.e. clients get the new size without
+     * having to do an explicit lok::Document::getDocumentSize() call.
      */
-    LOK_CALLBACK_PAGE_COUNT_CHANGED,
+    LOK_CALLBACK_DOCUMENT_SIZE_CHANGED,
 
     /**
      * The current part number is changed.
@@ -143,12 +143,12 @@ typedef enum
 
     /**
-     * Number of pages changed in the document.
+     * Size of the document changed.
      *
commit 84819b6f0c957965f43952d219c731d06b35f4d7
Author: Tor Lillqvist <tml at collabora.com>
Date:   Wed May 27 17:14:13 2015 +0300

    Improve error handling
